@@ -1,7 +1,9 @@
 #'@name ipdw
+#'
 #'@title Inverse Path Distance Weighting
 #'@description Interpolate geo-referenced point data using inverse path distance weighting.
 #'@author Joseph Stachelek
+#'
 #'@param spdf SpatialPointsDataFrame object
 #'@param costras RasterLayer. Cost raster
 #'@param range numeric. Range of interpolation neighborhood
@@ -10,7 +12,10 @@
 #'@param yearmon character. String specifying the name of the spdf
 #'@param removefile logical. Remove files after processing?
 #'@param step numeric. Number of sub loops to manage memory during raster processing.
+#'@param dist_power numeric. Distance decay power (p).
+#'
 #'@return RasterLayer
+#'
 #'@details This is a high level function that interpolates a 
 #'SpatialPointsDataFrame object in a single pass. 
 #'
@@ -20,13 +25,15 @@
 #'with a large sized cost rasters (grain x extent). In these cases, the 
 #'value of land areas should be increased to ensure that it is always 
 #'greater than the maximum accumulated cost path distance of any given geo-referenced point.
+#'
 #'@export
 #'@importFrom raster projection
+#'
 #'@examples
-#' #see vignette
+#' # see vignette
 
-'ipdw' <- function(spdf, costras, range, paramlist, overlapped = FALSE,
-					yearmon = "default", removefile = TRUE, step = 16){
+ipdw <- function(spdf, costras, range, paramlist, overlapped = FALSE,
+					yearmon = "default", removefile = TRUE, step = 16, dist_power = 1){
   
   if(!identical(raster::projection(spdf), raster::projection(costras))){
     stop("Point data projection and cost raster projections do not match,
@@ -38,8 +45,8 @@
   
   #ipdwInterp
   final.ipdw <- ipdwInterp(spdf, pathdists, paramlist, yearmon,
-  							removefile = TRUE, overlapped = overlapped)
+  							removefile = TRUE, overlapped = overlapped, 
+  							dist_power = dist_power)
   
   return(final.ipdw)  
-  
 }
